# Django Tools SocialNetworks

Simple Django app to manage a website social network links

## Installation

1. Install with pip install `django-tools-socialnetworks`.

2. Add `djtools.socialnetworks` to your INSTALLED_APPS setting like this:
```
INSTALLED_APPS = [
    ...
    'djtools.socialnetworks',
]
```
